/*

  RFID RC522 Modul 13.56 MHz (Card / Brick UID Reader)

  Parts required:
  - Arduino Board
  - RFID RC522 Modul 13.56 MHz
  - RFID MIFARE 1K Card or Brick

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 27 Jan 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <SPI.h>                                                        // include library SPI.h
#include <MFRC522.h>                                                    // include library MRFC522.h

#define RST_PIN         9                                               // set Reset to digital pin 10
#define SS_PIN          10                                              // set SDA to digital pin 9

MFRC522 mfrc522(SS_PIN, RST_PIN);                                       // create object from MRFC522 as mfrc522

MFRC522::MIFARE_Key key;

void setup() {
  Serial.begin(9600);                                                   // start Serial Monitor for communication
  while (!Serial);                                                      // wait for the Serial Monitor to start
  SPI.begin();                                                          // start SPI
  mfrc522.PCD_Init();                                                   // start mfrc522

  Serial.println(F("Put your card on the RFID RC522 Scanner....."));    // print text to Serial Monitor
  Serial.println();                                                     // print empty line to Serial Monitor
}

void loop() {
  if ( ! mfrc522.PICC_IsNewCardPresent())                               // card for new car on the RFID reader
    return;

  if ( ! mfrc522.PICC_ReadCardSerial())                                 // read the UID from the RFID reader
    return;

  Serial.print(F("Card UID:"));                                         // print text to Serial Monitor
  dump_byte_array(mfrc522.uid.uidByte, mfrc522.uid.size);               // print UID fra reader routine
  Serial.println();                                                     // print empty line to Serial Monitor
  Serial.print(F("PICC type: "));                                       // print text to Serial Monitor
  MFRC522::PICC_Type piccType = mfrc522.PICC_GetType(mfrc522.uid.sak);  // print PICC type from reader routine
  Serial.println(mfrc522.PICC_GetTypeName(piccType));                   // print text to Serial Monitor
  Serial.println();                                                     // print empty line to Serial Monitor

  delay(1000);                                                          // wait 1000ms
}

//   Routine to dump a byte array as hex values to Serial.
void dump_byte_array(byte *buffer, byte bufferSize) {
  for (byte i = 0; i < bufferSize; i++) {
    Serial.print(buffer[i] < 0x10 ? " 0" : " ");
    Serial.print(buffer[i], HEX);
  }
}
